Index: mandoline/ui/desktop_ui/browser_window.cc |
diff --git a/mandoline/ui/desktop_ui/browser_window.cc b/mandoline/ui/desktop_ui/browser_window.cc |
index a9987be1981e18b4725deb2e8ec7395d542290a2..069fa7d9ecc936aacb1f53031eb862a114aaf653 100644 |
--- a/mandoline/ui/desktop_ui/browser_window.cc |
+++ b/mandoline/ui/desktop_ui/browser_window.cc |
@@ -80,7 +80,7 @@ BrowserWindow::BrowserWindow(mojo::ApplicationImpl* app, |
web_view_(this) { |
mojo::ViewTreeHostClientPtr host_client; |
host_client_binding_.Bind(GetProxy(&host_client)); |
- mojo::CreateViewTreeHost(host_factory, host_client.Pass(), this, &host_); |
+ mus::CreateViewTreeHost(host_factory, host_client.Pass(), this, &host_); |
} |
void BrowserWindow::LoadURL(const GURL& url) { |
@@ -103,7 +103,7 @@ void BrowserWindow::LoadURL(const GURL& url) { |
void BrowserWindow::Close() { |
if (root_) |
- mojo::ScopedViewPtr::DeleteViewOrViewManager(root_); |
+ mus::ScopedViewPtr::DeleteViewOrViewManager(root_); |
else |
delete this; |
} |
@@ -143,9 +143,9 @@ float BrowserWindow::DIPSToPixels(float value) const { |
} |
//////////////////////////////////////////////////////////////////////////////// |
-// BrowserWindow, mojo::ViewTreeDelegate implementation: |
+// BrowserWindow, mus::ViewTreeDelegate implementation: |
-void BrowserWindow::OnEmbed(mojo::View* root) { |
+void BrowserWindow::OnEmbed(mus::View* root) { |
// BrowserWindow does not support being embedded more than once. |
CHECK(!root_); |
@@ -200,13 +200,13 @@ void BrowserWindow::OnEmbed(mojo::View* root) { |
} |
} |
-void BrowserWindow::OnConnectionLost(mojo::ViewTreeConnection* connection) { |
+void BrowserWindow::OnConnectionLost(mus::ViewTreeConnection* connection) { |
root_ = nullptr; |
delete this; |
} |
//////////////////////////////////////////////////////////////////////////////// |
// BrowserWindow, mojo::ViewTreeHostClient implementation: |
void BrowserWindow::OnAccelerator(uint32_t id, mojo::EventPtr event) { |
switch (static_cast<BrowserCommand>(id)) { |
@@ -325,7 +325,7 @@ void BrowserWindow::Layout(views::View* host) { |
//////////////////////////////////////////////////////////////////////////////// |
// BrowserWindow, private: |
-void BrowserWindow::Init(mojo::View* root) { |
+void BrowserWindow::Init(mus::View* root) { |
DCHECK_GT(root->viewport_metrics().device_pixel_ratio, 0); |
if (!aura_init_) |
aura_init_.reset(new AuraInit(root, app_->shell())); |
@@ -200,13 +200,13 @@ void BrowserWindow::OnEmbed(mojo::View* root) { |
} |
//////////////////////////////////////////////////////////////////////////////// |
-// BrowserWindow, mojo::ViewTreeHostClient implementation: |
+// BrowserWindow, mus::ViewTreeHostClient implementation: |
void BrowserWindow::OnAccelerator(uint32_t id, mojo::EventPtr event) { |
switch (static_cast<BrowserCommand>(id)) { |